import random
import os

SUBJECTS = ['animals', 'singers', 'countries']           # Holding all the subjects


def print_game_name():
    # Parameters: None
    # Print the game name to the screen

    print("""
    ##      ##      ######      ####       ##    ##########    ####       ####      ######      ####       ##
    ##      ##    ##      ##    ## ##      ##    ##      ##    ## ##     ## ##    ##      ##    ## ##      ##
    ##      ##    ##      ##    ##  ##     ##    ##      ##    ##  ##   ##  ##    ##      ##    ##  ##     ##
    ##      ##    ##      ##    ##   ##    ##    ##            ##   ## ##   ##    ##      ##    ##   ##    ##
    ##########    ##########    ##    ##   ##    ##    ####    ##    ##     ##    ##########    ##    ##   ##
    ##      ##    ##      ##    ##     ##  ##    ##      ##    ##           ##    ##      ##    ##     ##  ##
    ##      ##    ##      ##    ##      ## ##    ##      ##    ##           ##    ##      ##    ##      ## ##
    ##      ##    ##      ##    ##       ####    ##########    ##           ##    ##      ##    ##       ####
    """)


def print_game_board(game_board, lst_place):
    # Parameters: board, current place in list
    # Print the game board to the screen

    print(game_board[lst_place])


def get_random_word(subject):
    # Parameters: subject
    # Returns a random word from the text file

    try:
        with open(f'{subject}.txt') as f:
            return random.choice(list(f.read().splitlines()))

    except IOError:
        print("Open error")


def start(subject, secret_word):
    # Parameters: subject, secret_word
    # The full game function

    place = 0             # Holding the place, of the current drawing, in the board list
    board = ['''
       +---+
           |
           |
           |
           |
           |
     =========''', '''
       +---+
       |   |
           |
           |
           |
           |
     =========''', '''
       +---+
       |   |
       O   |
           |
           |
           |
     =========''', '''
       +---+
       |   |
       O   |
       |   |
           |
           |
     =========''', '''
       +---+
       |   |
       O   |
      /|   |
           |
           |
     =========''', '''
       +---+
       |   |
       O   |
      /|\  |
           |
           |
     =========''', '''
       +---+
       |   |
       O   |
      /|\  |
      /    |
           |
     =========''', '''
       +---+
       |   |
       O   |
      /|\  |
      / \  |
           |
     =========''']


    dashes = ''.join([c if c == ' ' else '-' for c in secret_word])
    guesses_left = 7
    letters_bank = []

    while guesses_left > 0 and not dashes == secret_word:
        print("SUBJECT: " + subject)
        print()

        print_game_board(board, place)
        print()
        print(dashes)
        print()
        print(str(guesses_left) + " guesses left")

        print("LETTERS BANK: ", end=" ")
        print([letter for letter in letters_bank])
        print()

        # Asks the user for character
        guess = input("Guess a character: ")

        # Checks if the input is one character
        if len(guess) != 1:
            print("Your guess must be one character!")

        # Checks if the input in in secret_word
        elif guess in secret_word or guess.lower() in secret_word:
            dashes = update_dashes(secret_word, dashes, guess.lower())

        elif guess not in letters_bank:
            guesses_left -= 1
            letters_bank.append(guess)
            place += 1

        # Clear the screen
        os.system('cls' if os.name == 'nt' else 'clear')

    if guesses_left < 1:
        print_game_board(board, place)
        print("GAME OVER! \nThe word was: " + str(secret_word))

    else:
        print_game_board(board, place)
        print("YOU WIN! \nThe word was: " + str(secret_word))


def update_dashes(secret, dash, guess):
    # Updates the string of dashes by replacing the dashes,
    # if the user manages to guess a character correctly

    result = ""

    for i in range(len(secret)):
        if secret[i] == guess:
            # Adds guess to string if guess is correctly
            result += guess

        else:
            # Add the dash at index i
            result += dash[i]

    return result


def main():
    # Start
    print_game_name()

    print("SUBJECTS:")
    for i, subject in enumerate(SUBJECTS, 1):
        print(f'[{i}] {subject}')

    i = 0
    print("Enter a subject number: ", end='')
    while i < 1 or i > len(SUBJECTS):
        i = int(input())
    subject = SUBJECTS[i - 1]
    secret_word = get_random_word(subject)

    # Clear the screen
    os.system('cls' if os.name == 'nt' else 'clear')

    start(subject, secret_word)


if __name__ == '__main__':
    main()
